@@ -5,16 +5,18 @@
 #' its fiducial confidence limits (CL) using a probit analysis
 #' according to Finney 1971, Wheeler et al. 2006, and Robertson et al. 2007.
 #' @usage LC_probit(formula, data, p = seq(1, 99, 1), weights,
-#'           subset = NULL, log_x = TRUE, het_sig = NULL, conf_level = NULL)
+#'           subset = NULL, log_x = TRUE, het_sig = NULL, conf_level = NULL,
+#'           long_output = TRUE)
 #' @param formula an object of class `formula` or one that can be coerced to that class): a symbolic description of the model to be fitted. The details of model specification are given under Details.
 #' @param data an optional data frame, list or environment (or object coercible by as.data.frame to a data frame) containing the variables in the model. If not found in data, the variables are taken from environment(formula), typically the environment from which `LC_probit` is called.
 #' @param p Lethal Concentration (LC) value for given p, example will return a LC50 value if p equals 50. If more than one LC value wanted specify by creating a vector.
 #' @param weights vector of 'prior weights' to be used in the fitting process. Should be a numeric vector and is required for analysis.
-#' @param subset allows for the data to be subset if desired. Default set to `NULL`.
-#' @param log_x default is `TRUE` and will calculate results using the antilog10 given that the x varaible has been `log10` tranformed. If `FALSE` results will not be back transformed.
+#' @param subset allows for the data to be subseted if desired. Default set to `NULL`.
+#' @param log_x default is `TRUE` and will calculate results using the antilog10 given that the x variable has been `log10` tranformed. If `FALSE` results will not be back transformed.
 #' @param het_sig significance level from person's chi square goodness-of-fit test (pgof) that is used to decide if a heterogeneity factor is used. `NULL` is set to 0.15.
 #' @param conf_level adjust confidence level as necessary or `NULL` set at 0.95.
-#' @return Returns a data frame with predicted LC for given p level, lower CL (LCL), upper CL (UCL), LCL and UCL distance away from LC (LCL_dis & UCL_dis; important for creating a plot), Pearson's chi square goodness-of-fit test (pgof), slope, intercept, slope and intercept p values and standard error, and LC variance.
+#' @param long_output default is `TRUE` which will return a tibble with all 19 variabless. If `FALSE` the tibble returned will consist of the p level, n, the predicted LC for given p level, lower and upper confidence limits and their distances.
+#' @return Returns a tibble with predicted LC for given p level, lower CL (LCL), upper CL (UCL), LCL and UCL distance away from LC (LCL_dis & UCL_dis; important for creating a plot), Pearson's chi square goodness-of-fit test (pgof), slope, intercept, slope and intercept p values and standard error, and LC variance.
 #' @references
 #'
 #' Finney, D.J., 1971. Probit Analysis, Cambridge University Press, Cambridge, England, ISBN: 052108041X
@@ -92,14 +94,14 @@
 #'
 #' p2
 #' @import ggplot2
-#' @import magrittr
 #' @import stats
+#' @import tibble
 #' @export
 
 # Function  LC_probit ----
 LC_probit <- function(formula, data, p = seq(1, 99, 1), weights,
                       subset = NULL, log_x = TRUE, het_sig = NULL,
-                      conf_level = NULL) {
+                      conf_level = NULL, long_output = TRUE) {
 
   model <- do.call("glm", list(formula = formula,
                                family = binomial(link = "probit"),
@@ -113,8 +115,7 @@ LC_probit <- function(formula, data, p = seq(1, 99, 1), weights,
   # pearson's goodness of fit test (pgof) returns a sigficance
   # value less than 0.150 (source: 'SPSS 24')
 
-  chi_square <- residuals.glm(model, type = "pearson") ^ 2 %>%
-                  sum()
+  chi_square <- sum(residuals.glm(model, type = "pearson") ^ 2)
 
   df <- df.residual(model)
 
@@ -260,26 +261,36 @@ LC_probit <- function(formula, data, p = seq(1, 99, 1), weights,
   }
 
   # Make a data frame from the data at all the different values
-  table <- data.frame(p = p,
-                      n = n,
-                      dose = dose,
-                      LCL = LCL,
-                      UCL = UCL,
-                      LCL_dis = LCL_dis,
-                      UCL_dis = UCL_dis,
-                      chi_square = chi_square,
-                      df = df,
-                      pgof_sig = pgof,
-                      h = het,
-                      slope = b1,
-                      slope_se = slope_se,
-                      slope_sig = slope_sig,
-                      intercept = b0,
-                      intercept_se = intercept_se,
-                      intercept_sig = intercept_sig,
-                      z = z_value,
-                      var_m = var_m)
-
+  if (long_output == TRUE) {
+   table <- tibble(p = p,
+                   n = n,
+                   dose = dose,
+                   LCL = LCL,
+                   UCL = UCL,
+                   LCL_dis = LCL_dis,
+                   UCL_dis = UCL_dis,
+                   chi_square = chi_square,
+                   df = df,
+                   pgof_sig = pgof,
+                   h = het,
+                   slope = b1,
+                   slope_se = slope_se,
+                   slope_sig = slope_sig,
+                   intercept = b0,
+                   intercept_se = intercept_se,
+                   intercept_sig = intercept_sig,
+                   z = z_value,
+                   var_m = var_m)
+  }
+  if (long_output == FALSE) {
+    table <- tibble(p = p,
+                    n = n,
+                    dose = dose,
+                    LCL = LCL,
+                    UCL = UCL,
+                    LCL_dis = LCL_dis,
+                    UCL_dis = UCL_dis)
+  }
   return(table)
 
 }
@@ -290,16 +301,18 @@ LC_probit <- function(formula, data, p = seq(1, 99, 1), weights,
 #' its fiducial confidence limits (CL) using a logit analysis
 #' according to Finney 1971, Wheeler et al. 2006, and Robertson et al. 2007.
 #' @usage LC_logit(formula, data, p = seq(1, 99, 1), weights,
-#'          subset = NULL, log_x = TRUE, het_sig = NULL, conf_level = NULL)
+#'          subset = NULL, log_x = TRUE, het_sig = NULL,
+#'          conf_level = NULL, long_output = TRUE)
 #' @param formula an object of class `formula` or one that can be coerced to that class): a symbolic description of the model to be fitted. The details of model specification are given under Details.
 #' @param data an optional data frame, list or environment (or object coercible by as.data.frame to a data frame) containing the variables in the model. If not found in data, the variables are taken from environment(formula), typically the environment from which `LC_logit` is called.
 #' @param p Lethal Concentration (LC) values for given p, example will return a LC50 value if p equals 50. If more than one LC value wanted specify by creating a vector.
 #' @param weights vector of 'prior weights' to be used in the fitting process. Should be a numeric vector and is required for analysis.
-#' @param log_x default is `TRUE` and will calculate results using the antilog10 given that the x varaible has been `log10` tranformed. If `FALSE` results will not be back transformed.
-#' @param subset allows for the data to be subset if desired. Default set to `NULL`.
+#' @param log_x default is `TRUE` and will calculate results using the antilog10 given that the x variable has been `log10` tranformed. If `FALSE` results will not be back transformed.
+#' @param subset allows for the data to be subseted if desired. Default set to `NULL`.
 #' @param het_sig significance level from person's chi square goodness-of-fit test that is used to decide if a heterogeneity factor is used. `NULL` is set to 0.15.
 #' @param conf_level adjust confidence level as necessary or `NULL` set at 0.95.
-#' @return Returns a data frame with predicted LC for given p level, lower CL (LCL), upper CL (UCL), LCL and UCL distance away from LC (LCL_dis & UCL_dis; important for creating a plot), Pearson's chi square goodness-of-fit test (pgof), slope, intercept, slope and intercept p values and standard error, and LC variance.
+#' @param long_output default is `TRUE` which will return a tibble with all 19 variabless. If `FALSE` the tibble returned will consist of the p level, n, the predicted LC for given p level, lower and upper confidence limits and their distances.
+#' @return Returns a tibble with predicted LC for given p level, lower CL (LCL), upper CL (UCL), LCL and UCL distance away from LC (LCL_dis & UCL_dis; important for creating a plot), Pearson's chi square goodness-of-fit test (pgof), slope, intercept, slope and intercept p values and standard error, and LC variance.
 #' @references
 #'
 #' Finney, D.J., 1971. Probit Analysis, Cambridge University Press, Cambridge, England, ISBN: 052108041X
@@ -382,7 +395,8 @@ LC_probit <- function(formula, data, p = seq(1, 99, 1), weights,
 # Function  LC_logit ----
 LC_logit <- function(formula, data, p = seq(1, 99, 1), weights,
                      subset = NULL, log_x = TRUE,
-                     het_sig = NULL, conf_level = NULL) {
+                     het_sig = NULL, conf_level = NULL,
+                     long_output = TRUE) {
 
   model <- do.call("glm", list(formula = formula,
                                family = binomial(link = "logit"),
@@ -396,8 +410,7 @@ LC_logit <- function(formula, data, p = seq(1, 99, 1), weights,
   # pearson's goodness of fit test (pgof) returns a sigficance
   # value less than 0.150 (source: 'SPSS 24')
 
-  chi_square <- residuals.glm(model, type = "pearson") ^ 2 %>%
-                  sum()
+  chi_square <- sum(residuals.glm(model, type = "pearson") ^ 2)
 
   df <- df.residual(model)
 
@@ -539,25 +552,36 @@ LC_logit <- function(formula, data, p = seq(1, 99, 1), weights,
 
 
   # Make a data frame from the data at all the different values
-  table <- data.frame(p = p,
-                      n = n,
-                      dose = dose,
-                      LCL = LCL,
-                      UCL = UCL,
-                      LCL_dis = LCL_dis,
-                      UCL_dis = UCL_dis,
-                      chi_square = chi_square,
-                      df = df,
-                      pgof_sig = pgof,
-                      h = het,
-                      slope = b1,
-                      slope_se = slope_se,
-                      slope_sig = slope_sig,
-                      intercept = b0,
-                      intercept_se = intercept_se,
-                      intercept_sig = intercept_sig,
-                      z = z_value,
-                      var_m = var_m)
+  if (long_output == TRUE) {
+    table <- tibble(p = p,
+                    n = n,
+                    dose = dose,
+                    LCL = LCL,
+                    UCL = UCL,
+                    LCL_dis = LCL_dis,
+                    UCL_dis = UCL_dis,
+                    chi_square = chi_square,
+                    df = df,
+                    pgof_sig = pgof,
+                    h = het,
+                    slope = b1,
+                    slope_se = slope_se,
+                    slope_sig = slope_sig,
+                    intercept = b0,
+                    intercept_se = intercept_se,
+                    intercept_sig = intercept_sig,
+                    z = z_value,
+                    var_m = var_m)
+  }
+  if (long_output == FALSE) {
+    table <- tibble(p = p,
+                    n = n,
+                    dose = dose,
+                    LCL = LCL,
+                    UCL = UCL,
+                    LCL_dis = LCL_dis,
+                    UCL_dis = UCL_dis)
+  }
 
   return(table)
 
