@@ -5,17 +5,19 @@
 #' its fiducial confidence limits (CL) using a probit analysis
 #' according to Finney 1971, Wheeler et al. 2006, and Robertson et al. 2007.
 #' @usage LT_probit(formula, data, p = seq(1, 99, 1), weights,
-#' subset = NULL, log_x = TRUE, het_sig = NULL, conf_level = NULL)
+#'           subset = NULL, log_x = TRUE, het_sig = NULL, conf_level = NULL,
+#'           long_output = TRUE)
 #' @param formula an object of class `formula` or one that can be coerced to that class: a symbolic description of the model to be fitted.
 #' @param data an optional data frame, list or environment (or object coercible by as.data.frame to a data frame) containing the variables in the model. If not found in data, the variables are taken from environment(formula), typically the environment from which `LT_probit` is called.
 #' @param p Lethal time (LT) values for given p, example will return a LT50 value if p equals 50. If more than one LT value desired specify by creating a vector.
 #'
 #' @param weights vector of 'prior weights' to be used in the fitting process. Should be a numeric vector and is required for analysis.
-#' @param subset allows for the data to be subset if desired. Default set to `NULL`.
-#' @param log_x Default is `TRUE` and will calculate results using the antilog10 given that the x varaible has been `log10` tranformed. If `FALSE` results will not be back transformed.
+#' @param subset allows for the data to be subseted if desired. Default set to `NULL`.
+#' @param log_x Default is `TRUE` and will calculate results using the antilog10 given that the x variable has been `log10` tranformed. If `FALSE` results will not be back transformed.
 #' @param het_sig significance level from person's chi square goodness-of-fit test that is used to decide if a heterogeneity factor is used. `NULL` is set to 0.15.
 #' @param conf_level  Adjust confidence level as necessary or `NULL` set at 0.95.
-#' @return Returns a data frame with predicted LT for given p level, lower CL (LCL), upper CL (UCL), LCL and UCL distance away from LT (LCL_dis & UCL_dis; important for creating a plot), Pearson's chi square goodness-of-fit test (pgof), slope, intercept, slope and intercept p values and standard error, and LT variance.
+#' @param long_output default is `TRUE` which will return a tibble with all 19 variabless. If `FALSE` the tibble returned will consist of the p level, n, the predicted LC for given p level, lower and upper confidence limits and their distances.
+#' @return Returns a tibble with predicted LT for given p level, lower CL (LCL), upper CL (UCL), LCL and UCL distance away from LT (LCL_dis & UCL_dis; important for creating a plot), Pearson's chi square goodness-of-fit test (pgof), slope, intercept, slope and intercept p values and standard error, and LT variance.
 #' @references
 #'
 #' Finney, D.J., 1971. Probit Analysis, Cambridge University Press, Cambridge, England, ISBN: 052108041X
@@ -43,7 +45,8 @@
 # Function  LT_probit ----
 LT_probit <- function(formula, data, p = seq(1, 99, 1),
                weights, subset = NULL, log_x = TRUE,
-               het_sig = NULL, conf_level = NULL) {
+               het_sig = NULL, conf_level = NULL,
+               long_output = TRUE) {
 
   model <- do.call("glm", list(formula = formula,
                                family = binomial(link = "probit"),
@@ -58,8 +61,7 @@ LT_probit <- function(formula, data, p = seq(1, 99, 1),
   # pearson's goodness of fit test (pgof) returns a sigficance
   # value less than 0.150 (source: 'SPSS 24')
 
-  chi_square <- residuals(model, type = "pearson") ^ 2 %>%
-                  sum()
+  chi_square <- sum(residuals(model, type = "pearson") ^ 2)
 
   df <- df.residual(model)
 
@@ -202,26 +204,37 @@ LT_probit <- function(formula, data, p = seq(1, 99, 1),
 
 
   # Make a data frame from the data at all the different values
-  table <- data.frame(p = p,
-                      n = n,
-                      time = time,
-                      LCL =  LCL,
-                      UCL =  UCL,
-                      LCL_dis = LCL_dis,
-                      UCL_dis =  UCL_dis,
-                      chi_square = chi_square,
-                      df = df,
-                      pgof_sig = pgof,
-                      h = het,
-                      slope = b1,
-                      slope_se = slope_se,
-                      slope_sig = slope_sig,
-                      intercept = b0,
-                      intercept_se = intercept_se,
-                      intercept_sig = intercept_sig,
-                      z = z_value,
-                      var_m = var_m)
+  if (long_output == TRUE) {
+    table <- tibble(p = p,
+                    n = n,
+                    time = time,
+                    LCL =  LCL,
+                    UCL =  UCL,
+                    LCL_dis = LCL_dis,
+                    UCL_dis =  UCL_dis,
+                    chi_square = chi_square,
+                    df = df,
+                    pgof_sig = pgof,
+                    h = het,
+                    slope = b1,
+                    slope_se = slope_se,
+                    slope_sig = slope_sig,
+                    intercept = b0,
+                    intercept_se = intercept_se,
+                    intercept_sig = intercept_sig,
+                    z = z_value,
+                    var_m = var_m)
+  }
 
+  if (long_output == FALSE) {
+    table <- tibble(p = p,
+                    n = n,
+                    time = time,
+                    LCL =  LCL,
+                    UCL =  UCL,
+                    LCL_dis = LCL_dis,
+                    UCL_dis =  UCL_dis)
+  }
   return(table)
 
 }
@@ -233,16 +246,18 @@ LT_probit <- function(formula, data, p = seq(1, 99, 1),
 #' its fiducial confidence limits (CL) using a logit analysis
 #' according to Finney 1971, Wheeler et al. 2006, and Robertson et al. 2007.
 #' @usage LT_logit(formula, data, p = seq(1, 99, 1), weights,
-#' subset = NULL, log_x = TRUE, het_sig = NULL, conf_level = NULL)
+#'           subset = NULL, log_x = TRUE, het_sig = NULL,
+#'           conf_level = NULL, long_output = TRUE)
 #' @param formula an object of class `formula` or one that can be coerced to that class: a symbolic description of the model to be fitted.
 #' @param data an optional data frame, list or environment (or object coercible by as.data.frame to a data frame) containing the variables in the model. If not found in data, the variables are taken from environment(formula), typically the environment from which `LT_logit` is called.
 #' @param p Lethal time (LT) values for given p, example will return a LT50 value if p equals 50. If more than one LT value desired specify by creating a vector.
 #' @param weights vector of 'prior weights' to be used in the fitting process. Should be a numeric vector and is required for analysis.
-#' @param subset allows for the data to be subset if desired. Default set to `NULL`.
-#' @param log_x Default is `TRUE` and will calculate results using the antilog10 given that the x varaible has been `log10` tranformed. If `FALSE` results will not be back transformed.
+#' @param subset allows for the data to be subseted if desired. Default set to `NULL`.
+#' @param log_x Default is `TRUE` and will calculate results using the antilog10 given that the x variable has been `log10` tranformed. If `FALSE` results will not be back transformed.
 #' @param het_sig significance level from person's chi sqaure goodness-of-fit test that is used to decide if a heterogeneity factor is used. `NULL` is set to 0.15.
 #' @param conf_level  Adjust confidence level as necessary or `NULL` set at 0.95.
-#' @return Returns a data frame with predicted LT for given p level, lower CL (LCL), upper CL (UCL), LCL and UCL distance away from LT (LCL_dis & UCL_dis; important for creating a plot), Pearson's chi sqaure goodness-of-fit test (pgof), slope, intercept, slope and intercept p values and standard error, and LT variance.
+#' @param long_output default is `TRUE` which will return a tibble with all 19 variabless. If `FALSE` the tibble returned will consist of the p level, n, the predicted LC for given p level, lower and upper confidence limits and their distances.
+#' @return Returns a tibble with predicted LT for given p level, lower CL (LCL), upper CL (UCL), LCL and UCL distance away from LT (LCL_dis & UCL_dis; important for creating a plot), Pearson's chi sqaure goodness-of-fit test (pgof), slope, intercept, slope and intercept p values and standard error, and LT variance.
 #' @references
 #'
 #' Finney, D.J., 1971. Probit Analysis, Cambridge University Press, Cambridge, England, ISBN: 052108041X
@@ -271,9 +286,8 @@ LT_probit <- function(formula, data, p = seq(1, 99, 1),
 # Function  LT_logit ----
 
 LT_logit <- function(formula, data, p = seq(1, 99, 1), weights = NULL,
-                     subset = NULL, log_x = TRUE,
-                     het_sig = NULL,
-                     conf_level = NULL) {
+                     subset = NULL, log_x = TRUE, het_sig = NULL,
+                     conf_level = NULL, long_output = TRUE) {
 
   model <- do.call("glm", list(formula = formula,
                                family = binomial(link = "logit"),
@@ -288,8 +302,7 @@ LT_logit <- function(formula, data, p = seq(1, 99, 1), weights = NULL,
   # pearson's goodness of fit test (pgof) returns a sigficance
   # value less than 0.150 (source: 'SPSS 24')
 
-  chi_square <- residuals(model, type = "pearson") ^ 2 %>%
-                  sum()
+  chi_square <- sum(residuals(model, type = "pearson") ^ 2)
 
   df <- df.residual(model)
   pgof <- pchisq(chi_square, df.residual(model), lower.tail = FALSE)
@@ -429,25 +442,36 @@ LT_logit <- function(formula, data, p = seq(1, 99, 1), weights = NULL,
 
 
   # Make a data frame from the data at all the different values
-  table <- data.frame(p = p,
-                      n = n,
-                      time = time,
-                      LCL = LCL,
-                      UCL = UCL,
-                      LCL_dis = LCL_dis,
-                      UCL_dis = UCL_dis,
-                      chi_square = chi_square,
-                      df = df,
-                      pgof_sig = pgof,
-                      h = het,
-                      slope = b1,
-                      slope_se = slope_se,
-                      slope_sig = slope_sig,
-                      intercept = b0,
-                      intercept_se = intercept_se,
-                      intercept_sig = intercept_sig,
-                      z = z_value,
-                      var_m = var_m)
+  if (long_output == TRUE) {
+    table <- tibble(p = p,
+                    n = n,
+                    time = time,
+                    LCL = LCL,
+                    UCL = UCL,
+                    LCL_dis = LCL_dis,
+                    UCL_dis = UCL_dis,
+                    chi_square = chi_square,
+                    df = df,
+                    pgof_sig = pgof,
+                    h = het,
+                    slope = b1,
+                    slope_se = slope_se,
+                    slope_sig = slope_sig,
+                    intercept = b0,
+                    intercept_se = intercept_se,
+                    intercept_sig = intercept_sig,
+                    z = z_value,
+                    var_m = var_m)
+  }
 
+  if (long_output == FALSE) {
+    table <- tibble(p = p,
+                    n = n,
+                    time = time,
+                    LCL = LCL,
+                    UCL = UCL,
+                    LCL_dis = LCL_dis,
+                    UCL_dis = UCL_dis)
+  }
   return(table)
 }
